@@ -73,9 +73,11 @@ var info =  new java.util.Hashtable ();
 info.put ("_IMAGE_", image);
 this.vwr.fm.loadImage (info, fileName, false);
 return errMsg = "OK - viewing " + fileName.substring (1);
-}if (out == null && (out = this.openOutputChannel (this.privateKey, fileName, false, false)) == null) return errMsg = "ERROR: canceled";
+}var isPngj = type.equals ("PNGJ");
+if (!isPngj) {
+if (out == null && (out = this.openOutputChannel (this.privateKey, fileName, false, false)) == null) return errMsg = "ERROR: canceled";
 fileName = out.getFileName ();
-var comment = null;
+}var comment = null;
 var stateData = null;
 params.put ("date", this.vwr.apiPlatform.getDateFormat ("8601"));
 if (type.startsWith ("JP")) {
@@ -90,11 +92,11 @@ comment = (!asBytes ? this.getWrappedState (null, null, image, null) : "");
 comment = "";
 } else if (type.startsWith ("PNG")) {
 comment = "";
-var isPngj = type.equals ("PNGJ");
 if (isPngj) {
 var outTemp = this.getOutputChannel (null, null);
 this.getWrappedState (fileName, scripts, image, outTemp);
 stateData = outTemp.toByteArray ();
+if (out == null && (out = this.openOutputChannel (this.privateKey, fileName, false, false)) == null) return errMsg = "ERROR: canceled";
 } else if (rgbbuf == null && !asBytes && !params.containsKey ("captureMode")) {
 stateData = (this.getWrappedState (null, scripts, image, null)).getBytes ();
 }if (stateData != null) {
@@ -210,11 +212,12 @@ return this.handleOutputToFile (params, true);
 Clazz.defineMethod (c$, "getOutputChannel", 
 function (fileName, fullPath) {
 if (!this.vwr.haveAccess (JV.Viewer.ACCESS.ALL)) return null;
-if (fileName != null) {
+var isCache = (fileName != null && fileName.startsWith ("cache://"));
+if (fileName != null && !isCache) {
 fileName = this.getOutputFileNameFromDialog (fileName, -2147483648, null);
 if (fileName == null) return null;
 }if (fullPath != null) fullPath[0] = fileName;
-var localName = (JU.OC.isLocal (fileName) ? fileName : null);
+var localName = (JU.OC.isLocal (fileName) || isCache ? fileName : null);
 try {
 return this.openOutputChannel (this.privateKey, localName, false, false);
 } catch (e) {
